import request from '@/utils/request'

// 查询检查类型列表
export function listCheckType(query) {
  return request({
    url: '/system/check-type/list',
    method: 'get',
    params: query
  })
}

// 查询检查类型详细
export function getCheckType(checkTypeId) {
  return request({
    url: '/system/check-type/' + checkTypeId,
    method: 'get'
  })
}

// 新增检查类型
export function addCheckType(data) {
  return request({
    url: '/system/check-type',
    method: 'post',
    data: data
  })
}

// 修改检查类型
export function updateCheckType(data) {
  return request({
    url: '/system/check-type',
    method: 'put',
    data: data
  })
}

// 删除检查类型
export function delCheckType(checkTypeId) {
  return request({
    url: '/system/check-type/' + checkTypeId,
    method: 'delete'
  })
}

// 查询检查方法列表
export function listCheckMethod(query) {
  return request({
    url: '/system/check-method/list',
    method: 'get',
    params: query
  })
}

// 查询检查部位列表
export function listCheckPart(query) {
  return request({
    url: '/system/check-part/list',
    method: 'get',
    params: query
  })
}

// 查询检查套餐列表
export function listCheckPackage(query) {
  return request({
    url: '/system/check-package/list',
    method: 'get',
    params: query
  })
}

// 根据ID查询检查套餐详情
export function getCheckPackage(id) {
  return request({
    url: `/system/check-package/${id}`,
    method: 'get'
  })
}

// 新增检查套餐
export function addCheckPackage(data) {
  return request({
    url: '/system/check-package',
    method: 'post',
    data: data
  })
}

// 修改检查套餐
export function updateCheckPackage(data) {
  return request({
    url: '/system/check-package',
    method: 'put',
    data: data
  })
}

// 删除检查套餐
export function delCheckPackage(id) {
  return request({
    url: `/system/check-package/${id}`,
    method: 'delete'
  })
}